Package: MDTS
Title: Detection of de novo deletion in targeted sequencing trios
Version: 1.30.0
Authors@R: person("Jack M..", "Fu", email = "jmfu@jhsph.edu", role = c("aut", "cre"))
Description: A package for the detection of de novo copy number deletions in targeted sequencing of trios with high sensitivity and positive predictive value.
Depends: R (>= 3.5.0)
Imports: GenomicAlignments, GenomicRanges, IRanges, Biostrings,
        DNAcopy, Rsamtools, parallel, stringr
Suggests: testthat, knitr
VignetteBuilder: knitr
License: Artistic-2.0
Encoding: UTF-8
RoxygenNote: 6.0.1
biocViews: StatisticalMethod, Technology, Sequencing,
        TargetedResequencing, Coverage, DataImport
git_url: https://git.bioconductor.org/packages/MDTS
git_branch: RELEASE_3_22
git_last_commit: 2e2c502
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 04:53:55 UTC; biocbuild
Author: Jack M.. Fu [aut, cre]
Maintainer: Jack M.. Fu <jmfu@jhsph.edu>

# Generated by roxygen2: do not edit by hand

export(calcBins)
export(calcCounts)
export(calcMD)
export(denovoDeletions)
export(getMetaData)
export(normalizeCounts)
export(segmentMD)
export(visualizeDeletion)
import(GenomicAlignments)
import(GenomicRanges)
import(parallel)
importFrom(Biostrings,getSeq)
importFrom(DNAcopy,CNA)
importFrom(DNAcopy,segment)
importFrom(GenomicAlignments,coverage)
importFrom(GenomicAlignments,readGAlignments)
importFrom(IRanges,IRanges)
importFrom(Rsamtools,ScanBamParam)
importFrom(Rsamtools,scanBamFlag)

## Overview

MDTS provides the necessary infrastructure to take raw bam files of targeted sequencing trios to produce de novo deletion calls of high sensitivity and low false positives. Our method benefits tremendously from pooling information from across many trios to determine regions of interest, normalize read-depth, and to filter candidate deletion signals.

To install please use `install_github('jmf47/MDTS', ref="R-3.4", build_vignettes=TRUE)`.

To view the vignette after installing MDTS use `vignette("mdts", package="MDTS")`.

#' Circular Binary Segmentation on Minimum Distances
#'
#' This function will return a GRanges object containing the copy number 
#'	segments of all families in the input minimum distance matrix. It calls
#'	segment() from DNAcopy (alpha=0.001, undo.splits="sdundo", undo.SD=4).
#' @param md The minimum distance matrix produced by calcMD.
#' @param bins The set of bins determined by calcBins.
#' @param alpha Controls the alpha option in calling DNAcopy::segment()
#' @param undo.splits Controls the undo.splits option in DNAcopy::segment()
#' @param undo.SD Controls the undo.SD option in calling DNAcopy::segment()
#' @param mc.cores The number of cores to use for multi-threaded analysis. 
#' Defaults to 1.
#' @keywords segmentMD
#' @importFrom DNAcopy CNA
#' @importFrom DNAcopy segment
#' @examples 
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	load(system.file("extdata", 'counts.RData', package = "MDTS"))
#'	load(system.file("extdata", 'pD.RData', package = "MDTS"))
#'	mCounts <- normalizeCounts(counts, bins)
#'	md <- calcMD(mCounts, pD)
#'	cbs <- segmentMD(md, bins)
#' @export
#' @return A \code{data.frame} containing the segmented regions based to be
#' parsed by denovoDeletions()
#' minimum distance.
segmentMD <- function(md, bins, alpha=0.001, undo.splits='sdundo', undo.SD=4, 
                     mc.cores=1){
	segs <- mclapply(1:(dim(md)[2]), .segmentMDHelper, 
            md=md, bins=bins, alpha=alpha, 
            undo.splits = undo.splits, undo.SD=undo.SD, 
            mc.cores=mc.cores)
	segs.out <- do.call(rbind, segs)
	return(segs.out)
}

## Helper function
.segmentMDHelper <- function(i, md, bins, alpha, undo.splits, undo.SD){
      set.seed(137)
      message(paste0("Processing family number: ", i))
      md_sub <- md[,i,drop=FALSE]
      cna <- DNAcopy::CNA(genomdat=md_sub, chrom=as.vector(seqnames(bins)),
                maploc=start(bins), data.type="logratio", 
                sampleid=colnames(md_sub), presorted=TRUE)
      cbs <- DNAcopy::segment(cna, alpha=alpha, 
                              undo.splits=undo.splits, undo.SD=undo.SD)
      
      segRows <- cbs$segRows
      out <- data.frame(start=segRows[,1], end=segRows[,2], 
                       seg.mean=cbs$output$seg.mean, family=colnames(md_sub))
      return(out)
}

#' Denovo Deletion Calling
#'
#' This function will return a single GRanges object containing all denovo 
#' deletions that passed filtering from a Circular Binary Segmentation object 
#' with supplementary information.
#' @param cbs The output from segmentMD().
#' @param mCounts The normalized counts matrix output by normalizeCounts().
#' @param bins The set of bins determined by calcBins().
#' @keywords denovoDeletions
#' @importFrom IRanges IRanges
#' @examples 
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	load(system.file("extdata", 'counts.RData', package = "MDTS"))
#'	load(system.file("extdata", 'pD.RData', package = "MDTS"))
#'	mCounts = normalizeCounts(counts, bins)
#'	md = calcMD(mCounts, pD)
#'	cbs = segmentMD(md, bins)
#'	denovo = denovoDeletions(cbs, mCounts, bins)
#' @export
#' @return A \code{GRanges} object that reports all detected denovo deletions
#' passing requite filters.
denovoDeletions = function(cbs, mCounts, bins){
	dels <- GRanges()
	print("Selecting Candidate de Novo deletions")
	candidates <- cbs[abs(cbs$seg.mean+1)<0.3,]
	candidates$num.segs <- candidates$end-candidates$start+1

	print("Calculating problematic bins")
	win <- 0.5
	raw <- abs(mCounts)<win
	raw_perc <- apply(raw, 1, mean)
	raw_perc <- vapply(raw_perc+1/dim(mCounts)[2], min, double(1))
	filter_ind <- which(raw_perc<0.95)
	
	print("Filtering candidates by problematic bins")
	candidates$num.segs.filtered <- vapply(seq_len(dim(candidates)[1]), 
            .countBadBins, FUN.VALUE=double(1), candidates, filter_ind)
	
	deletions <- candidates[(candidates$num.segs.filtered/
            candidates$num.segs)<0.5,]
	deletions_gr <- GRanges(seqnames=seqnames(bins)[deletions$start],
            IRanges::IRanges(GenomicRanges::start(bins)[deletions$start],
            GenomicRanges::end(bins)[deletions$end]),
            m=deletions$seg.mean, famid=deletions$family)
	return(deletions_gr)
}

.countBadBins <- function(i, candidates, filter_ind){
      candidate <- candidates[i,]
      num.segs.bad <- sum((filter_ind>=candidate$start & 
                                filter_ind<=candidate$end))
      return(num.segs.bad)
}

#' Creating the raw count matrix
#'
#' This function will return a matrix of read counts where ecah column is a 
#' sample, and each row is a bin.
#' @param metaData A table in the format of the output of getMetaData().
#' @param bins The set of bins determined by calcBins().
#' @param rl The read length of the experiment.
#' @param mc.cores The number of cores to use for multi-threaded analysis. 
#' Defaults to 1.
#' @keywords calcCounts
#' @importFrom Rsamtools ScanBamParam
#' @examples 
#' \dontrun{
#'	pD <- getMetaData(
#'	'https://raw.githubusercontent.com/JMF47/MDTSData/master/data/pD.ped')
#'	genome = BSgenome.Hsapiens.UCSC.hg19
#'	map_file <- 
#'	"https://raw.githubusercontent.com/JMF47/MDTSData/master/data/chr1.map.bw"
#'	bins = calcBins(pD, n=5, rl=100, med=150, min=5, genome, map_file)
#'	}
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	load(system.file("extdata", 'counts.RData', package = "MDTS"))
#'	counts
#' @export
#' @return A \code{data.frame} that contains the counts for each sample in the 
#' \code{metaData} input that fall into each segment of \code{bins}.
calcCounts <- function(metaData, bins, rl, mc.cores=1){
	cov_list <- mclapply(metaData$bam_path, .extractCovBins, bins, 
	                    mc.cores=mc.cores)
	cov_matrix <- do.call(cbind, cov_list)
	colnames(cov_matrix) <- metaData$subj_id
	count_matrix <- cov_matrix*width(bins)/rl
	return(count_matrix)
}

## Helper function
.extractCovBins <- function(path, target){
      flag <- Rsamtools::scanBamFlag(isUnmappedQuery=FALSE, isDuplicate=FALSE)
      param <- Rsamtools::ScanBamParam(what=character(), flag=flag)      
      ga <- readGAlignments(path, param=param)
      cov <- coverage(ga)
      cov <- cov[match(seqlevels(target), names(cov))]
      binned <- binnedAverage(target, cov, "count")
      return(binned$count)
}

#' The MDTS package for Detection of Denovo Deletions from Targeted Sequencing 
#' Data Using Minimum-Distance
#'
#' @name MDTS-package
#' @aliases MDTS
#' @docType package
#' @import parallel
#' @import GenomicRanges
#' @import GenomicAlignments
NULL

#' Calculating the normalized M scores
#'
#' This function will return a matrix of normalized M scores where ecah column 
#' is a sample, and each row is a bin.
#' @param counts A matrix of raw coverage output by calcCounts().
#' @param bins The set of bins determined by calcBins().
#' @param mc.cores The number of cores to use for multi-threaded analysis. 
#' @param GC Whether to loess adjust for GC. Defaults to TRUE.
#' @param map Whether to loess adjust for mappability. Defaults to TRUE.
#' Defaults to 1.
#' @keywords normalizeCounts
#' @examples 
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	load(system.file("extdata", 'counts.RData', package = "MDTS"))
#'	load(system.file("extdata", 'pD.RData', package = "MDTS"))
#'	mCounts <- normalizeCounts(counts, bins)
#' @export
#' @return A \code{data.frame} of normalized counts. Each column is a sample,
#' and each row is a entry of \code{bins}.
normalizeCounts <- function(counts, bins, GC=TRUE, map=TRUE, mc.cores=1){
	message("Log Transforming Counts")
	log_counts <- log(counts+1, 2)
	intermediate <- t(t(log_counts) - apply(log_counts, 2, stats::median))
	res <- intermediate - apply(intermediate, 1, stats::median)
	
	if(GC){
	      message("GC Adjust")
	      res <- do.call(cbind, mclapply(seq_len(dim(res)[2]), function(i){
	            control <- stats::loess.control(trace.hat="approximate")
                  res <- stats::residuals(stats::loess(res[,i]~bins$GC, 
                        control = control))
	      }, mc.cores=mc.cores))
	}
	if(map){
	      message("Mappability Adjust")
            loess_ind <- which(bins$mappability<1)
	      res <- do.call(cbind, mclapply(seq_len(dim(res)[2]), function(i){
                  tmp <- res[,i]
                  tmp[loess_ind] <- stats::residuals(stats::loess(
                        tmp[loess_ind]~bins$mappability[loess_ind]))
                  return(tmp)
	      }, mc.cores=mc.cores))
	}
	colnames(res) <- colnames(counts)
	return(res)
}

#' Sample driven calculation of bins for counting
#'
#' This function will randomly select a sample of bam files to calculate dynamic
#' MDTS bins for subsequent read-depth analysis.
#' @param metaData A table in the format of the output of getMetaData().
#' @param n The number of subsamples to use.
#' @param readLength The read length of the experiment.
#' @param medianCoverage The median number of reads across sub-samples to reach 
#' before creating a new bin.
#' @param minimumCoverage The miminum number of coverage across all sub-samples 
#' required to create the proto-region.
#' @param genome The BSGenome object that assists in calculations of the GC 
#' content of the bins.
#' @param mappabilityFile A path to the bigwig file of 100mer mappability of the
#' corresponding genome.
#' @param seed Sets the seed so results are reproducible. Defaults to 1337.
#' @importFrom Rsamtools scanBamFlag
#' @importFrom  Biostrings getSeq
#' @importFrom GenomicAlignments readGAlignments
#' @importFrom GenomicAlignments coverage
#' @keywords calcBins
#' @examples 
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	bins
#' @export
#' @return Returns a \code{GRanges} object depicting the dynamic bins that MDTS 
#' calculates.
calcBins <- function(metaData, n, readLength, medianCoverage, minimumCoverage,
                     genome, mappabilityFile, seed=1337){
	set.seed(seed)
      metaSub <- metaData[sample(seq_len(n), replace=FALSE),]
	hasChr <- FALSE

	message("Reading coverage information of subsamples")
	covs <- vector('list', n)
	names(covs) <- metaSub[['bam_path']]
	for(i in metaSub[['bam_path']]){
	      reads = .extractCov(i)
		if(sum(stringr::str_detect(names(reads), "chr"))>0)
			hasChr=TRUE
		if(hasChr)
			names(reads) <- stringr::str_replace(names(reads), "chr", "")
		reads <- reads[names(reads) %in% 1:22]
		covs[[i]] <- reads
	}

	message("Calculating Proto-regions")
	rle_threshold <- lapply(covs, function(x) x>=minimumCoverage)
	rle_track <- rle_threshold[[1]]
		for(i in seq_len(n)[-1]){rle_track = rle_track + rle_threshold[[i]]}
	rle_track0 <- rle_track>0

	bins <- lapply(seq_len(22), .processChr, 
	              rle_track0, covs, readLength, medianCoverage)
	bins_out <- suppressWarnings(
	      do.call(c, bins[vapply(bins, length, integer(1))>0]))
	message("Bin segmentation complete")

      seqlevels(bins_out) <- paste0("chr", seqlevels(bins_out))
	seqs <- Biostrings::getSeq(genome, bins_out)
	
	message("Calculating GC content")
	GC <- vapply(seqs, .calcGC, double(1))
	bins_out$GC <- GC

	message("Calculating mappability")
	map_track <- import(mappabilityFile)
	ol <- findOverlaps(bins_out, map_track)
	segment_sums <- by(rep(1, length(ol)), queryHits(ol), sum)
	segment_sums_1 <- as.numeric(names(segment_sums)[which(segment_sums==1)])
	map <- rep(0, length(segment_sums))
	### For mappability=1 segments, no need to process
	map[segment_sums_1] <- map_track$score[subjectHits(ol)
            [match(segment_sums_1, queryHits(ol))]]
	### For mappability<1, process
	ol_remain = ol[!queryHits(ol) %in% segment_sums_1]
	map[unique(queryHits(ol_remain))] = vapply(unique(queryHits(ol_remain)), 
            .mappabilityHelper, double(1), ol_remain, bins_out, map_track)
	### Put the composite results together
	bins_out$mappability = map

	message("Filtering bins based on GC and Mappability")
	rm_ind <- unique(c(which(bins_out$mappability<0.75), 
            which(bins_out$GC>0.85 | bins_out$GC<0.15)))
	if(length(rm_ind)>0){bins_out = bins_out[-rm_ind]}

	if(!hasChr)
            seqlevels(bins_out) <- stringr::str_replace(seqlevels(bins_out), 
            "chr", "")
	return(bins_out)
}

## Helper functions
.extractCov <- function(path){
      message(path)
      flag <- Rsamtools::scanBamFlag(isUnmappedQuery = FALSE, 
                                     isDuplicate = FALSE)
      param <- Rsamtools::ScanBamParam(what = character(), flag=flag)      
      ga <- GenomicAlignments::readGAlignments(path, param=param)
      return(GenomicAlignments::coverage(ga))
}

.processChr = function(chr, proto_info, covs, rl, med){
      message(paste0("Selecting Proto-regions in Chr ", chr))
      proto_region <- proto_info[[chr]]
      if(sum(proto_region)>0){
            proto_gr <- GRanges(seqnames=chr, IRanges::IRanges(proto_region))
            proto_gr_covs_rle <- lapply(covs, function(x) x[proto_gr])
            # proto_gr_covs <- lapply(proto_gr_covs_rle, function(x) 
            #       lapply(x, sum))
            proto_gr_covs <- lapply(seq_along(proto_gr_covs_rle), function(x) 
                  lapply(proto_gr_covs_rle[[x]], sum))
            proto_gr_covs_mat <- apply(do.call(rbind, proto_gr_covs), 2, 
                  as.numeric)
            proto_gr_covs_mat_normed <- t(t(proto_gr_covs_mat)/rl)
            proto_gr_covs_mat_med <- apply(proto_gr_covs_mat_normed, 2, 
                  stats::median)
            proto_gr$reads <- proto_gr_covs_mat_med
            proto_gr_select <- proto_gr[proto_gr$reads>=med]
            
            if(length(proto_gr_select)>0){
                  message(paste0("Segmenting Chr ", chr, " Proto-regions"))
                  # chr_out <- lapply(proto_gr_select, .divideSegs, covs, rl, med)
                  chr_out <- lapply(seq_along(proto_gr_select), .divideSegs, 
                                    proto_gr_select, covs, rl, med)
                  chr_out <- do.call(c, chr_out)
                  return(chr_out)
            }else{
                  return(NULL)
            }
      }else{
            return(NULL)
      }
}
.extractCounts <- function(cov_list){
      return(suppressWarnings((as.numeric(unlist(cov_list)))))
}
# .divideSegs <- function(seg, covs, rl, med){
.divideSegs <- function(i, proto_gr_select, covs, rl, med){
      seg = proto_gr_select[i]
      cov_sub <- lapply(covs, function(x) x[seg])
      cov_sub_mat <- do.call(rbind, lapply(cov_sub, .extractCounts))
      cov_sub_cs_normed <- t(apply(cov_sub_mat, 1, cumsum))/rl
      medz <- apply(cov_sub_cs_normed, 2, stats::median)
      medzCut <- floor(medz/med)
      changePoint <- vapply(seq_len(max(medzCut)), function(x){
            min(which(medzCut==x))}, integer(1))
      changePoint <- c(0, changePoint)
            changePoint[length(changePoint)] <- width(seg)
      gr_out <- GRanges(seqnames=seqnames(seg),
            IRanges::IRanges(start(seg)+changePoint[-length(changePoint)],
            start(seg)+changePoint[-1]-1))
      gr_medz <- medz[changePoint]
      gr_out$median_count <- gr_medz-med*(seq_len(length(gr_medz))-1)
      return(gr_out)
}
.calcGC <- function(biostring){
      string <- as.character(biostring)
      return(stringr::str_count(string, "G|C")/nchar(string))
}
.mappabilityHelper <- function(i, ol, bins, map){
      overlaps <- pintersect(map[subjectHits(ol)[queryHits(ol)==i]], bins[i])
      percentOverlap <- width(overlaps) / width(bins[i])
      return(sum(percentOverlap*overlaps$score))
}

#' Constructor for metadata
#'
#' This function allows constructor of phenotype information necessary for 
#' downstream analysis. See format of required fields. Function will also 
#' rearrange the rows such that trios are grouped together - with proband first,
#' mother second, and father third. 
#' @param path The path pointing to the file that contains information on each
#' subject in the dataset.
#' @param id The column name that identifies each sample. Defaults to 'subj_id'.
#' @param familyId The column name that identifies which family the sample
#' belongs to. Defaults to 'family_id'.
#' @param fatherId The column name that identifies the id of the father. 
#' Defaults to 'father_id'.
#' @param motherId The column name that identifies the id of the mother.
#' Defaults to 'mother_id'.
#' @param bamPath The column name that identifies where to find the bam file
#' for each subject. Defaults to 'bam_path'.
#' @examples 
#'	meta <- getMetaData(
#'	'https://raw.githubusercontent.com/JMF47/MDTSData/master/data/pD.ped')
#' @export
#' @return Returns a \code{data.frame} of required sample information for 
#' running MDTS.
getMetaData <- function(path, id="subj_id", familyId="family_id", 
                        fatherId="father_id", motherId="mother_id", 
                        bamPath="bam_path"){
	tab <- utils::read.table(path, header=TRUE, colClasses = "character")
	hdrs <- c(id, familyId, fatherId, motherId, bamPath)
	if(sum(hdrs %in% colnames(tab))<length(hdrs))
	      stop("One of the required variables is missing.")
	col_ind <- match(hdrs, colnames(tab))
	tab_sel <- tab[,col_ind]
	colnames(tab_sel) <- c("subj_id", "family_id", "father_id", "mother_id",
	                       "bam_path")
	proband_id <- sort(tab_sel$subj_id[
	      tab_sel[[fatherId]] %in% tab_sel[[id]] & 
		tab_sel[[motherId]] %in% tab_sel[[id]]])
	
	tab_proband <- tab_sel[match(proband_id, tab_sel[[id]]),]
	tab_mother <- tab_sel[match(tab_proband$mother_id, tab_sel[[id]]),]
	tab_father <- tab_sel[match(tab_proband$father_id, tab_sel[[id]]),]

	tab_out <- tab[,col_ind]
	tab_out[seq(1, length(proband_id)*3, by=3),] <- tab_proband
	tab_out[seq(2, length(proband_id)*3, by=3),] <- tab_mother
	tab_out[seq(3, length(proband_id)*3, by=3),] <- tab_father
	return(tab_out)
}

#' Calculating the Minimum Distance matrix
#'
#' This function will return a matrix of minimum distances where ecah column is 
#' a family, and each row is a bin.
#' @param mCounts A matrix of normalized coverage output by normalizedCounts().
#' @param metaData A table in the format of the output of metaData().
#' @keywords calcMD
#' @examples 
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	load(system.file("extdata", 'counts.RData', package = "MDTS"))
#'	load(system.file("extdata", 'pD.RData', package = "MDTS"))
#'	mCounts <- normalizeCounts(counts, bins)
#'	md <- calcMD(mCounts, pD)
#' @export
#' @return A \code{data.frame} of minimum distances. Each column is a trio,
#' while each row is an entry in \code{bins}
calcMD = function(mCounts, metaData){
	proband_ind <- which(metaData$father_id %in% metaData$subj_id)
	proband <- metaData$subj_id[proband_ind]

	father_ind <- match(metaData$father_id[proband_ind], metaData$subj_id)
	mother_ind <- match(metaData$mother_id[proband_ind], metaData$subj_id)

	md1 <- mCounts[,proband_ind] - mCounts[,mother_ind]
	md2 <- mCounts[,proband_ind] - mCounts[,father_ind]
	md <- md1
	      md[abs(md1)>abs(md2)] <- md2[abs(md1)>abs(md2)]

	colnames(md) <- proband
	return(md)
}

## ----echo=F, message=F, warning=F---------------------------------------------
library(MDTS); library(BSgenome.Hsapiens.UCSC.hg19)
setwd(system.file("extdata", package="MDTS"))
load('pD.RData')
pD

## ----echo=FALSE, message=FALSE------------------------------------------------
library(MDTS)

## ----eval=F, warning=F--------------------------------------------------------
# library(MDTS); library(BSgenome.Hsapiens.UCSC.hg19)
# # Using the raw data from MDTSData
# devtools::install_github("jmf47/MDTSData")
# setwd(system.file("data", package="MDTSData"))
# 
# # Importing the pedigree file that includes information on where to locate the
# # raw bam files
# pD <- getMetaData("pD.ped")
# 
# # Information on the GC content and mappability to estimate GC and mappability
# # for the MDTS bins
# genome <- BSgenome.Hsapiens.UCSC.hg19; map_file = "chr1.map.bw"
# 
# # This command now subsets 5 samples to determine MDTS bins
# # pD is the metaData matrix from getMetaData()
# # n is the number of samples to examine to calculate the bins
# # readLength is the sequencing read length
# # minimumCoverage is the minimum read depth for a location to be included
# #     in a proto region
# # medianCoverage is the median number of reads across the n samples in a bin
# bins <- calcBins(metaData=pD, n=5, readLength=100, minimumCoverage=5,
#                 medianCoverage=150, genome=genome, mappabilityFile=map_file)

## ----eval=F-------------------------------------------------------------------
# # pD is the phenotype matrix
# # bins is the previously calculated MDTS bins
# # rl is the sequencing read length
# counts = calcCounts(pD, bins, rl=100)

## ----message=FALSE, warning=F-------------------------------------------------
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))

## -----------------------------------------------------------------------------
bins

## -----------------------------------------------------------------------------
head(counts)

## ----warning=F----------------------------------------------------------------
# counts is the raw read depth of [MDTS bins x samples]
# bins is the previously calculated MDTS bins
mCounts <- normalizeCounts(counts, bins)

## ----warning=F----------------------------------------------------------------
# mCounts is the normalized read depth of [MDTS bins x samples]
# bins is the previously calculated MDTS bins
# pD is the phenotype matrix
md <- calcMD(mCounts, pD)

## ----warning=FALSE, message=FALSE, warning=F----------------------------------
# md is the Minimum Distance of [MDTS bins x trio]
# bins is the previously calculated MDTS bins
# mCounts is the normalized read depth of [MDTS bins x samples]
cbs <- segmentMD(md=md, bins=bins)
denovo <- denovoDeletions(cbs, mCounts, bins)

## -----------------------------------------------------------------------------
denovo

## -----------------------------------------------------------------------------
sessionInfo()

#' Visualization for deletions
#'
#' This function plots the raw read information from the location of interest 
#' for a trio.
#' @param deletion A GRanges object in the format of the output of 
#' denovoDeletions().
#' @param bins The set of bins determined by calcBins().
#' @param metaData A table in the format of the output of getMetaData().
#' @param mCounts A matrix of normalized coverage output by normalizedCounts().
#' @param md The minimum distance matrix output by calcMD()
#' @param save If TRUE will save plot to current working directory instead of 
#' rendering.
#' @keywords visualizeDeletion
#' @examples 
#' \dontrun{
#'	load(system.file("extdata", 'bins.RData', package = "MDTS"))
#'	load(system.file("extdata", 'counts.RData', package = "MDTS"))
#'	load(system.file("extdata", 'pD.RData', package = "MDTS"))
#'	mCounts <- normalizeCounts(counts, bins)
#'	md <- calcMD(mCounts, pD)
#'	cbs <- segmentMD(md, bins)
#'	denovo <- denovoDeletions(cbs, mCounts, bins)
#'	visualizeDeletion(denovo[1], bins, pD, mCounts, md)
#'	}
#' @return The file name if the plot was saved.
#' @export
visualizeDeletion = function(deletion, bins, metaData, mCounts, md, save=FALSE){
	window <- 1000
	famid <- metaData$family_id[metaData$subj_id==deletion$famid]
	metaData_sub <- metaData[stringr::str_detect(metaData$family_id, famid),]
	row_inds <- subjectHits(findOverlaps(deletion, bins))
	col_inds <- match(metaData_sub$subj_id, colnames(mCounts))
	
	id <- paste0(famid, "-", seqnames(deletion), ":", start(deletion), 
	            "-", end(deletion), ".pdf")
	if(save==TRUE){
		pdf(width=30, height=8, file=id)	
	}else{
		dev.new(width=30, height=8)	
	}
	.visualizeFamily(famid, deletion, window, row_inds, col_inds, pD, mCounts)
	dev.off()
	return(id)
}

### Helper functions
.pullReads = function(bam_path, bait){
      flag1 <- Rsamtools::scanBamFlag(isPaired=TRUE, isFirstMateRead=TRUE, 
            hasUnmappedMate=FALSE, isDuplicate=FALSE, 
            isSecondaryAlignment=FALSE)
      flag2 <- Rsamtools::scanBamFlag(isPaired=TRUE, isFirstMateRead=FALSE, 
            hasUnmappedMate=FALSE, isDuplicate=FALSE, 
            isSecondaryAlignment=FALSE)
      sbp1 <- Rsamtools::ScanBamParam(flag=flag1, 
            what=c("qname", "rname", "pos", "isize", "cigar"), which=bait)
      sbp2 <- Rsamtools::ScanBamParam(flag=flag2, 
            what=c("qname", "rname", "pos", "isize", "cigar"), which=bait)
      gal1 <- GenomicAlignments::readGAlignments(file=bam_path, param=sbp1)
      gal1 <- as(gal1, "GRanges")
      gal2 <- GenomicAlignments::readGAlignments(file=bam_path, param=sbp2)
      gal2 <- as(gal2, "GRanges")
      
      qnames_keep <- gal1$qname[gal1$qname %in% gal2$qname]
      GR1 <- gal1[match(qnames_keep, gal1$qname)]
      GR2 <- gal2[match(qnames_keep, gal2$qname)]
      return(GRangesList(GR1, GR2))
}

.visualize = function(GRL, track, window, title, denote, coll, scale){
      GR1 <- GRL[[1]]
      GR2 <- GRL[[2]]
      del <- track
      start(del) <- start(del) + window
      end(del) <- end(del)- window
      frags <- countOverlaps(del, GR1)+ countOverlaps(del, GR2)
      coords <- c(start(GR1), start(GR2), end(GR1), end(GR2))
      plot(c(start(track), end(track)), c(0, length(GR1)+1), ty="n", 
           main=paste0(title, " M= ", denote), 
           ylab="", xaxt="n", cex.lab=scale, cex.axis=scale*.8, cex.main=scale, 
           cex.sub=scale, xlab="", col=coll, col.axis=coll, col.sub=coll, 
           col.main=coll, col.lab=coll)
      j <- 0.1
      cls <- rep("#ffb90f", length(GR1))
      cls[which(strand(GR1)=="-")] <- "#6495ed"
      rect(xleft=start(GR1), xright=end(GR1), ytop = 1:length(GR1)-j, 
           ybot = 0:(length(GR1)-1)-j, col=cls, border=cls)
      rect(xleft=start(GR2), xright=end(GR2), ytop = 1:length(GR2)-j, 
           ybot = 0:(length(GR2)-1)-j, col=cls, border=cls)
      segments(x0 = end(GR1), x1=start(GR2), y0 = 1:length(GR1)-j-0.5, 
               y1 = 1:length(GR2)-j-0.5, lwd=0.1, col= cls)
      z <- width(track)-2*window
      text(x=(start(track)+end(track))/2, y=length(GR1)-length(GR1)/20, 
           labels=paste0(z, "bp"), cex=scale, col=coll)
      text(x=(start(track)+end(track))/2, length(GR1)/20, 
           labels=paste0(frags, " reads"), cex=scale, col=coll)
      ylims <- par("usr")[3:4]
      rect(xleft=start(track)+window, xright=end(track)-window, ytop = ylims[2],
           ybot=ylims[1], col=rgb(0, 0, 0, 0.2), border=rgb(0,0,0,0)) 
}

.visualizeFamily = function(famid, bait, window, row_inds, col_inds, pD, 
            mCounts, scale=4, col1 = rgb(0, 146, 146, max=255), 
            col2 = rgb(255, 109, 182, max=255)){
      sub <- pD[pD$family_id==famid,]
      label <- paste0(seqnames(bait), ":", start(bait), "-", end(bait))
      bamids <- as.character(sub$bamid)
      bamids <- sub$bam_path
      start(bait) <- start(bait)-window; end(bait) = end(bait)+window
      
      cands1 <- .pullReads(bamids[1], bait)
      cands2 <- .pullReads(bamids[2], bait)
      cands3 <- .pullReads(bamids[3], bait)
      
      res <- mCounts[row_inds, ,drop=FALSE]
      i1 <- which(colnames(res)==sub$subj_id[1])
      i2 <- which(colnames(res)==sub$subj_id[2])
      i3 <- which(colnames(res)==sub$subj_id[3])
      md1 <- res[,i1,drop=FALSE]-res[,i2,drop=FALSE]
      md2 <- res[,i1,drop=FALSE]-res[,i3,drop=FALSE]; md = md1
      md[abs(md1)>abs(md2)] <- md2[abs(md1)>abs(md2)]
      md <- mean(md); md = round(md, 3)
      res <- apply(res, 2, mean)
      res <- round(res, 3)
      
      layout(matrix(c(1, 2, 3, 4, 5, 6, 7, 8, 9, rep(10, 3)), 2, 6, byrow=TRUE),
             widths=c(0.5, 0.5, rep(5, 4)), heights = c(4, 0.1))
      par(mar=rep(0,4))
      plot(c(0, 1), c(0,1), xlab="", ylab="", xaxt="n", yaxt="n", 
           type="n", main="", xaxs="i", yaxs="i", bty="n")
      text(x=0.6, y=0.5, srt=90, paste0(famid, " - MD = ", md), cex=4, pos=3)
      plot(c(0, 1), c(0,1), xlab="", ylab="", xaxt="n", yaxt="n", 
           type="n", main="", xaxs="i", yaxs="i", bty="n")
      text(x=0.6, y=.5, srt=90, label, cex=4, pos=3)
      par(xpd=NA)
      text(x=1.2, y=.5, srt=90, paste0(length(row_inds), " bins"), pos=3, cex=4)
      par(xpd=FALSE)
      par(mar=c(scale, scale*3, scale, scale))
      # minM <- stats::quantile(res, 0.3)-1
      # maxM <- stats::quantile(res, 0.97)+1
      minM <- min(res)
      maxM <- max(res)
      plot_wid = (maxM-minM)
      hist(res, main="", xlim=c(minM, maxM), breaks=seq(-10, 10, by=0.3), 
           ylab="Hist M Scores", col="grey", cex.lab=scale*.8, 
           cex.axis=scale*.7, cex.main=scale, cex.sub=scale, xlab="")
      plot_lims <- par("usr")
      ylim <- plot_lims[3:4]
      lens <- (ylim[2]-ylim[1])/30
      ynotches <- seq(ylim[1], ylim[2], by = lens)
      rect(xleft=res[i1]-plot_wid/100, xright=res[i1]+plot_wid/100, 
           ytop=ynotches[seq(1, length(ynotches), by=3)]+lens, 
           ybot=ynotches[seq(1, length(ynotches), by=3)], col=1)
      rect(xleft=res[i2]-plot_wid/100, xright=res[i2]+plot_wid/100, 
           ytop=ynotches[seq(2, length(ynotches), by=3)]+lens, 
           ybot=ynotches[seq(2, length(ynotches), by=3)], col=col1, bord=col1)
      rect(xleft=res[i3]-plot_wid/100, xright=res[i3]+plot_wid/100, 
           ytop=ynotches[seq(3, length(ynotches), by=3)]+lens, 
           ybot=ynotches[seq(3, length(ynotches), by=3)], col=col2, bord=col2)
      
      par(xpd=FALSE)
      par(mar=rep(5,4))
      .visualize(cands1, bait, window, "Proband", 
                 denote=res[i1], coll=1, scale=scale)
      .visualize(cands2, bait, window, "Parent 1", 
                 denote=res[i2], coll=col1, scale=scale)
      .visualize(cands3, bait, window, "Parent 2", 
                 denote=res[i3], coll=col2, scale=scale)	
      
      par(mar=rep(0,4))
      plot(c(0,1), c(0,1), type="n", axes=FALSE, xlab="", ylab="")
      plot(c(0,1), c(0,1), type="n", axes=FALSE, xlab="", ylab="")
      plot(c(0,1), c(0,1), type="n", axes=FALSE, xlab="", ylab="")
      par(xpd=NA)
      plot(c(0,3), c(0,1), type="n", axes=FALSE, xlab="", ylab="")
      rect(xleft=0.6, xright=0.7, ybot=1.2, ytop=1.4, 
           bord="#ffb90f", col="#ffb90f")
      rect(xleft=1.7, xright=1.8, ybot=1.2, ytop=1.4, 
           bord="#6495ed", col="#6495ed")
      text(x=1, y=1.3, labels="+ Strand Reads", cex=scale*.8)
      text(x=2.1, y=1.3, labels="- Strand Reads", cex=scale*.8)
      par(xpd=FALSE)
}

---
author: "Jack Fu"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteEngine{knitr::knitr}
  %\VignetteIndexEntry{Title of your vignette}
  %\usepackage[UTF-8]{inputenc}
---

## Overview

MDTS provides the necessary infrastructure to take raw bam files of targeted 
sequencing trios to produce de novo deletion calls of high sensitivity and low 
false positives. Our method benefits tremendously from pooling information from 
across many trios to determine regions of interest, normalize read-depth, and to
filter candidate deletion signals.

MDTS is broken down into the following major steps:

1. Calculating the MDTS bins
2. Determinig the read-depth of the bins for each sample
3. Normalizing the read-depth
4. Creating the Minimum Distance for each trio
5. Call de novo deletions and filter

## Raw Data

Preprocessed sample data is included with the package `MDTS`, but should you be 
interested in the raw files, they can be found in the github repo 
`jmf47/MDTSdata`. It includes:

1. 21 simulated bam files (7 trios)
      + Sequencing read length of 100bp 
      + 1 true de novo deletion in family F4
2. A bw file that includes the 100mer mappability of chr1
3. A pedigree file 
      + Records the trio kinships 
      + Records the file paths to the raw bam files of each sample
      
```{r, echo=F, message=F, warning=F}
library(MDTS); library(BSgenome.Hsapiens.UCSC.hg19)
setwd(system.file("extdata", package="MDTS"))
load('pD.RData')
pD
```

## 1. Calculating MDTS Bins

One innovation of our method is that the bins to determine sequencing read depth
is calculated based on the empirical capture. These bins can be significantly 
different from the standard practice of using probe design coordinates to create
bins. Furthermore, our binning process allows the bins to be smaller in regions 
of high capture, and vice verse in low capture. This dynamic scaling of the bin 
size makes efficient use of varying depths of coverage - allowing us to call 
deletions with finer resolution in areas of higher coverage.

The general approach is first to examine the mapped coverage of a subset of the 
full dataset across the entire genome. Basepairs that are covered passed a 
certain threshold in at least one sample is selected as a proto-region. 
Proto-regions are subdvided into non-overlapping bins such that the median 
number of reads falling into each bin meets a specified level spcified by the 
*medianCoverage* parameter. The choice of *medianCoverage* is a tradeoff between
sensitivity and false positives. A larger *medianCoverage* decreases sensitivity
and false positives. For our publication, we used *medianCoverage=160*, and for 
this example we used *medianCoverage=150*.

Information on GC content and mappability of the bins are also calculated at 
this stage. As a result, MDTS requires a BSgenome object that is consistent with
the reference annotation the bam files were aligned to, as well as a mappability
bigwig that contains mappability information in windows consistent with 
sequencing read length. In our example, we require `BSgenome.Hsapiesn.UCSC.hg19`
and 100mer mappability.

** In general you will need a bw file that contains the information for all
autosomes 1-22 (unlike the bw file only for chr1 included in the example). **
This is the link to some hg19 mappability bw files:
http://rohsdb.cmb.usc.edu/GBshape/cgi-bin/hgFileUi?db=hg19&g=wgEncodeMapability

This portion of the vignette example uses raw data from `MDTSData`. However 
the resulting bins are included in the `data` directory of MDTS as a `.RData`.

```{r, echo=FALSE, message=FALSE}
library(MDTS)
```

```{r, eval=F, warning=F}
library(MDTS); library(BSgenome.Hsapiens.UCSC.hg19)
# Using the raw data from MDTSData
devtools::install_github("jmf47/MDTSData")
setwd(system.file("data", package="MDTSData")) 

# Importing the pedigree file that includes information on where to locate the 
# raw bam files
pD <- getMetaData("pD.ped")

# Information on the GC content and mappability to estimate GC and mappability 
# for the MDTS bins
genome <- BSgenome.Hsapiens.UCSC.hg19; map_file = "chr1.map.bw"

# This command now subsets 5 samples to determine MDTS bins
# pD is the metaData matrix from getMetaData()
# n is the number of samples to examine to calculate the bins
# readLength is the sequencing read length
# minimumCoverage is the minimum read depth for a location to be included 
#     in a proto region
# medianCoverage is the median number of reads across the n samples in a bin
bins <- calcBins(metaData=pD, n=5, readLength=100, minimumCoverage=5, 
                medianCoverage=150, genome=genome, mappabilityFile=map_file)
```

## 2. Calculating coverage of MDTS bins

Given a set of dynamic MDTS bins, we can proceed to calculate the number of 
reads that fall into these bins for the entirety of our sample. We organize the 
number of reads as a matrix, where each column is a sample, and each row 
corresponds to a bin. This portion of the vignette is a continuation of the 
usage of the raw data from `MDTSdata` above. However the resulting `counts` 
matrix is also shipped as a `rda` in `MDTS`.

```{r, eval=F}
# pD is the phenotype matrix
# bins is the previously calculated MDTS bins
# rl is the sequencing read length
counts = calcCounts(pD, bins, rl=100)
```

The MDTS bins, raw counts, and pedigree files are included with `MDTS` and can 
be loaded as follows:
```{r, message=FALSE, warning=F}
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))
```
The MDTS bins are
```{r}
bins
```
The count matrix where each column is a sample and each row is a bin:
```{r}
head(counts)
```

## 3. Normalizing the read-depth

After obtaining the raw read-depth matrix, MDTS calculates a vector M score 
matrix of the same organization - each row corresponds to a row and each column 
a sample. The M score is based on a log2 transformation, followed by median 
polish, and GC and mappability adjust via a loess smoother. The resulting M 
scores have critical values where (0, -1, <-4) are generally consistent with 2, 
1, and 0 copy numbers [barring Copy Number Polymorphisms].

```{r, warning=F}
# counts is the raw read depth of [MDTS bins x samples]
# bins is the previously calculated MDTS bins
mCounts <- normalizeCounts(counts, bins)
```

## 4. Creating the Minimum Distance for each trio

The second advantage of MDTS is the use of Minimum Distances for candidate de 
novo deletion identification. The assumption underlying the development of the 
Minimum Distance is that it is vastly more likely for a deletion to be inherited
than de novo if the proband shares a deletion with one of the parents in the 
trio. Based on that assumption, the Minimum Distance is calculated per family - 
bin combination. For each bin, the Minimum Distance is smallest (in absolute 
terms) difference between the proband's M score and both parents'. 

For example, if the M scores are (-1, -1, 0) for a proband and the 2 parents 
respectively, a situation consistent with an inherited deletion in the proband 
from parent 1, the Minimum Distance of the 2 possible pairwise comparisons is 0.
On the other hand, if the M scores are (-1, 0, 0) for the proband and the 2 
parents, the Minimum Distance stands out at -1, and is consistent with a de novo
deletion. 

To calculate the Minimum Distance of the dataset, MDTS takes as input the M 
score matrix. The output matrix is organized where each row corresponds still to
a bin, but each column now refers to a trio.

```{r, warning=F}
# mCounts is the normalized read depth of [MDTS bins x samples]
# bins is the previously calculated MDTS bins
# pD is the phenotype matrix
md <- calcMD(mCounts, pD)
```

## 5. Call de novo deletions and filter

Using the Minimum Distance matrix calculated above, MDTS uses the tried and true
Circular Binary Segmentation method to infer deletion states. Inferred candidate
de novo deletions are further filtered to remove likely false positive signals 
that arose out of regions of highly variable read-depth (generally indicative of
sequence artifacts or polymorphic events).

```{r, warning=FALSE, message=FALSE, warning=F}
# md is the Minimum Distance of [MDTS bins x trio]
# bins is the previously calculated MDTS bins
# mCounts is the normalized read depth of [MDTS bins x samples]
cbs <- segmentMD(md=md, bins=bins)
denovo <- denovoDeletions(cbs, mCounts, bins)
```

In our example, the output is a single detected de novo deletion in family F4:

```{r}
denovo
```

No signals were picked up from the CNP region or elsewhere.

## 6. SessionInfo

```{r}
sessionInfo()
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getMetaData.R
\name{getMetaData}
\alias{getMetaData}
\title{Constructor for metadata}
\usage{
getMetaData(path, id = "subj_id", familyId = "family_id",
  fatherId = "father_id", motherId = "mother_id", bamPath = "bam_path")
}
\arguments{
\item{path}{The path pointing to the file that contains information on each
subject in the dataset.}

\item{id}{The column name that identifies each sample. Defaults to 'subj_id'.}

\item{familyId}{The column name that identifies which family the sample
belongs to. Defaults to 'family_id'.}

\item{fatherId}{The column name that identifies the id of the father. 
Defaults to 'father_id'.}

\item{motherId}{The column name that identifies the id of the mother.
Defaults to 'mother_id'.}

\item{bamPath}{The column name that identifies where to find the bam file
for each subject. Defaults to 'bam_path'.}
}
\value{
Returns a \code{data.frame} of required sample information for 
running MDTS.
}
\description{
This function allows constructor of phenotype information necessary for 
downstream analysis. See format of required fields. Function will also 
rearrange the rows such that trios are grouped together - with proband first,
mother second, and father third.
}
\examples{
meta <- getMetaData(
'https://raw.githubusercontent.com/JMF47/MDTSData/master/data/pD.ped')
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/normalizeCounts.R
\name{normalizeCounts}
\alias{normalizeCounts}
\title{Calculating the normalized M scores}
\usage{
normalizeCounts(counts, bins, GC = TRUE, map = TRUE, mc.cores = 1)
}
\arguments{
\item{counts}{A matrix of raw coverage output by calcCounts().}

\item{bins}{The set of bins determined by calcBins().}

\item{GC}{Whether to loess adjust for GC. Defaults to TRUE.}

\item{map}{Whether to loess adjust for mappability. Defaults to TRUE.
Defaults to 1.}

\item{mc.cores}{The number of cores to use for multi-threaded analysis.}
}
\value{
A \code{data.frame} of normalized counts. Each column is a sample,
and each row is a entry of \code{bins}.
}
\description{
This function will return a matrix of normalized M scores where ecah column 
is a sample, and each row is a bin.
}
\examples{
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))
mCounts <- normalizeCounts(counts, bins)
}
\keyword{normalizeCounts}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/MDTS-package.R
\docType{package}
\name{MDTS-package}
\alias{MDTS-package}
\alias{MDTS}
\title{The MDTS package for Detection of Denovo Deletions from Targeted Sequencing 
Data Using Minimum-Distance}
\description{
The MDTS package for Detection of Denovo Deletions from Targeted Sequencing 
Data Using Minimum-Distance
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calcBins.R
\name{calcBins}
\alias{calcBins}
\title{Sample driven calculation of bins for counting}
\usage{
calcBins(metaData, n, readLength, medianCoverage, minimumCoverage, genome,
  mappabilityFile, seed = 1337)
}
\arguments{
\item{metaData}{A table in the format of the output of getMetaData().}

\item{n}{The number of subsamples to use.}

\item{readLength}{The read length of the experiment.}

\item{medianCoverage}{The median number of reads across sub-samples to reach 
before creating a new bin.}

\item{minimumCoverage}{The miminum number of coverage across all sub-samples 
required to create the proto-region.}

\item{genome}{The BSGenome object that assists in calculations of the GC 
content of the bins.}

\item{mappabilityFile}{A path to the bigwig file of 100mer mappability of the
corresponding genome.}

\item{seed}{Sets the seed so results are reproducible. Defaults to 1337.}
}
\value{
Returns a \code{GRanges} object depicting the dynamic bins that MDTS 
calculates.
}
\description{
This function will randomly select a sample of bam files to calculate dynamic
MDTS bins for subsequent read-depth analysis.
}
\examples{
load(system.file("extdata", 'bins.RData', package = "MDTS"))
bins
}
\keyword{calcBins}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/segmentMD.R
\name{segmentMD}
\alias{segmentMD}
\title{Circular Binary Segmentation on Minimum Distances}
\usage{
segmentMD(md, bins, alpha = 0.001, undo.splits = "sdundo", undo.SD = 4,
  mc.cores = 1)
}
\arguments{
\item{md}{The minimum distance matrix produced by calcMD.}

\item{bins}{The set of bins determined by calcBins.}

\item{alpha}{Controls the alpha option in calling DNAcopy::segment()}

\item{undo.splits}{Controls the undo.splits option in DNAcopy::segment()}

\item{undo.SD}{Controls the undo.SD option in calling DNAcopy::segment()}

\item{mc.cores}{The number of cores to use for multi-threaded analysis. 
Defaults to 1.}
}
\value{
A \code{data.frame} containing the segmented regions based to be
parsed by denovoDeletions()
minimum distance.
}
\description{
This function will return a GRanges object containing the copy number 
segments of all families in the input minimum distance matrix. It calls
segment() from DNAcopy (alpha=0.001, undo.splits="sdundo", undo.SD=4).
}
\examples{
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))
mCounts <- normalizeCounts(counts, bins)
md <- calcMD(mCounts, pD)
cbs <- segmentMD(md, bins)
}
\keyword{segmentMD}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualizeDeletion.R
\name{visualizeDeletion}
\alias{visualizeDeletion}
\title{Visualization for deletions}
\usage{
visualizeDeletion(deletion, bins, metaData, mCounts, md, save = FALSE)
}
\arguments{
\item{deletion}{A GRanges object in the format of the output of 
denovoDeletions().}

\item{bins}{The set of bins determined by calcBins().}

\item{metaData}{A table in the format of the output of getMetaData().}

\item{mCounts}{A matrix of normalized coverage output by normalizedCounts().}

\item{md}{The minimum distance matrix output by calcMD()}

\item{save}{If TRUE will save plot to current working directory instead of 
rendering.}
}
\value{
The file name if the plot was saved.
}
\description{
This function plots the raw read information from the location of interest 
for a trio.
}
\examples{
\dontrun{
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))
mCounts <- normalizeCounts(counts, bins)
md <- calcMD(mCounts, pD)
cbs <- segmentMD(md, bins)
denovo <- denovoDeletions(cbs, mCounts, bins)
visualizeDeletion(denovo[1], bins, pD, mCounts, md)
}
}
\keyword{visualizeDeletion}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/denovoDeletions.R
\name{denovoDeletions}
\alias{denovoDeletions}
\title{Denovo Deletion Calling}
\usage{
denovoDeletions(cbs, mCounts, bins)
}
\arguments{
\item{cbs}{The output from segmentMD().}

\item{mCounts}{The normalized counts matrix output by normalizeCounts().}

\item{bins}{The set of bins determined by calcBins().}
}
\value{
A \code{GRanges} object that reports all detected denovo deletions
passing requite filters.
}
\description{
This function will return a single GRanges object containing all denovo 
deletions that passed filtering from a Circular Binary Segmentation object 
with supplementary information.
}
\examples{
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))
mCounts = normalizeCounts(counts, bins)
md = calcMD(mCounts, pD)
cbs = segmentMD(md, bins)
denovo = denovoDeletions(cbs, mCounts, bins)
}
\keyword{denovoDeletions}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calcCounts.R
\name{calcCounts}
\alias{calcCounts}
\title{Creating the raw count matrix}
\usage{
calcCounts(metaData, bins, rl, mc.cores = 1)
}
\arguments{
\item{metaData}{A table in the format of the output of getMetaData().}

\item{bins}{The set of bins determined by calcBins().}

\item{rl}{The read length of the experiment.}

\item{mc.cores}{The number of cores to use for multi-threaded analysis. 
Defaults to 1.}
}
\value{
A \code{data.frame} that contains the counts for each sample in the 
\code{metaData} input that fall into each segment of \code{bins}.
}
\description{
This function will return a matrix of read counts where ecah column is a 
sample, and each row is a bin.
}
\examples{
\dontrun{
pD <- getMetaData(
'https://raw.githubusercontent.com/JMF47/MDTSData/master/data/pD.ped')
genome = BSgenome.Hsapiens.UCSC.hg19
map_file <- 
"https://raw.githubusercontent.com/JMF47/MDTSData/master/data/chr1.map.bw"
bins = calcBins(pD, n=5, rl=100, med=150, min=5, genome, map_file)
}
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
counts
}
\keyword{calcCounts}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/calcMD.R
\name{calcMD}
\alias{calcMD}
\title{Calculating the Minimum Distance matrix}
\usage{
calcMD(mCounts, metaData)
}
\arguments{
\item{mCounts}{A matrix of normalized coverage output by normalizedCounts().}

\item{metaData}{A table in the format of the output of metaData().}
}
\value{
A \code{data.frame} of minimum distances. Each column is a trio,
while each row is an entry in \code{bins}
}
\description{
This function will return a matrix of minimum distances where ecah column is 
a family, and each row is a bin.
}
\examples{
load(system.file("extdata", 'bins.RData', package = "MDTS"))
load(system.file("extdata", 'counts.RData', package = "MDTS"))
load(system.file("extdata", 'pD.RData', package = "MDTS"))
mCounts <- normalizeCounts(counts, bins)
md <- calcMD(mCounts, pD)
}
\keyword{calcMD}
